@@ -63,6 +63,16 @@
         <source>Videos</source>
         <translation type="unfinished">Videos</translation>
     </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="10"/>
+        <source>Added to Clipboard</source>
+        <translation type="unfinished">Agregado al Portapapeles</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="10"/>
+        <source>ERROR: Nothing selected to paste</source>
+        <translation type="unfinished">ERROR: Nada seleccionado para pegar</translation>
+    </message>
     <message>
         <location filename="../error.cpp" line="10"/>
         <source>Not enough space to proceed.</source>
@@ -96,9 +106,9 @@
     </message>
 </context>
 <context>
-    <name>ClipWindow</name>
+    <name>Clipboard</name>
     <message>
-        <location filename="../clipwindow.cpp" line="10"/>
+        <location filename="../clipboard.cpp" line="10"/>
         <source>Clipboard</source>
         <translation type="unfinished">Portapapeles</translation>
     </message>
@@ -107,7 +117,7 @@
     <name>Bookmarks</name>
     <message>
         <location filename="../bookmarks.cpp" line="10"/>
-        <source>Booksmarks</source>
+        <source>Bookmarks</source>
         <translation type="unfinished">Favoritos</translation>
     </message>
     <message>
@@ -634,8 +644,8 @@
     </message>
     <message>
         <location filename="../compressdlg.cpp" line="10"/>
-        <source>Compression method</source>
-        <translation type="unfinished">Método de compresión</translation>
+        <source>Compression</source>
+        <translation type="unfinished">Compresión</translation>
     </message>
     <message>
         <location filename="../compressdlg.cpp" line="10"/>
